@@ -7,10 +7,13 @@ pos=NULL,arrow.len=.05,arrow.col="black",add=FALSE,bars=FALSE,within=FALSE,col=c
 error.bars.by(x,data=data,x.cat=TRUE,ylab =ylab,xlab=xlab,main=main,ylim= ylim,
  eyes=eyes,alpha=alpha,sd=sd,labels=labels, v.labels=NULL, pos=pos, 
  arrow.len=arrow.len,add=add,bars=bars,within=within,colors=col, 
- legend=0,density=density,...)
-     } else {if(!missing(group)) {  error.bars.by(x,group=group,x.cat=TRUE,ylab =ylab,xlab=xlab,main=main,ylim= ylim, eyes=eyes,alpha=.05,sd=sd,labels=labels, 
+ legend=0,density=density,stats=stats,...)
+     } else {
+      if(!missing(group)) {  error.bars.by(x,group=group,x.cat=TRUE,ylab =ylab,xlab=xlab,main=main,ylim= ylim, eyes=eyes,alpha=.05,sd=sd,labels=labels, 
      v.labels=NULL, pos=pos, arrow.len=arrow.len, add=add,bars=bars, within=within, 
-     colors=col, legend=0,density=density,...)}  else {   #no grouping variable, this is the normal case
+     colors=col, legend=0,density=density,stats=stats,...)}  else {
+     
+  #no grouping variable, this is the normal case
      
     SCALE=.5   #scale the width of the cats eyes
     if(is.null(stats)) {
@@ -23,6 +26,7 @@ error.bars.by(x,data=data,x.cat=TRUE,ylab =ylab,xlab=xlab,main=main,ylim= ylim,
     	}  else { x.stats <- stats
     	          z <- dim(x.stats)[1]
     	          names <- rownames(stats)
+    	          if(is.null(x.stats$se) ) x.stats$se <- x.stats$sd/sqrt(x.stats$n-1)
     	}
     	min.x <- min(x.stats$mean,na.rm=TRUE)
     	max.x <- max(x.stats$mean,na.rm=TRUE)
@@ -64,7 +68,7 @@ error.bars.by(x,data=data,x.cat=TRUE,ylab =ylab,xlab=xlab,main=main,ylim= ylim,
       s <- c(1:z)   #this allows us to address each one separately
     	        if(bars) {arrows(mp[s],x.stats$mean[s]-ci[s]* x.stats$se[s],mp[s],x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)} else { 
     	       
-    	        if(is.null(x.stats$values)) {
+   if(is.null(x.stats$values)) {
     	 arrows(s[s],x.stats$mean[s]-ci[s]* x.stats$se[s],s[s],x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3,col=arrow.col) } else {
     	 arrows(x.stats$values,x.stats$mean[s]-ci[s]* x.stats$se[s],x.stats$values,x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3, col=arrow.col)}
  	 
