@@ -43,7 +43,12 @@ function(y,x,m=NULL, data, mod=NULL, z=NULL, n.obs=NULL,use="pairwise",n.iter=50
     if(is.null(mod)) {nmod<- 0} else {nmod<- length(mod)}
      var.names <- list(IV=x,DV=y,med=m,mod=mod,z=z,ex=ex)
   
-  if(any(!(unlist(var.names) %in% colnames(data)))) {stop ("Variable names not specified correctly")}                                      
+ # if(any(!(unlist(var.names) %in% colnames(data)))) {stop ("Variable names not specified correctly")} 
+  if(any( !(unlist(var.names) %in% colnames(data)) )) {
+     select <- unlist(var.names)
+  cat("\nOops! Variable names are incorrect. Offending items are ", select[which(!(select %in% colnames(data)))],"\n")
+ stop("I am stopping because the variable names are incorrect.  See above.")}
+                                     
     if(ncol(data) == nrow(data)) {raw <- FALSE 
             if(nmod > 0) {stop("Moderation Analysis requires the raw data") } else {data <- data[c(y,x,m,z),c(y,x,m,z)]} 
                  } else { data <- data[,c(y,x,m,z,ex)]
@@ -134,15 +139,16 @@ if (nmod > 0 ) {
 
      	xy.matrix <- C[c(x,m),y,drop=FALSE]   #this is the matrix of correlations with the criterion
 
-#this next section adds the intercept to the regressions 
+#this next section adds the intercept to the regressions
+
  C.int <- matrix(NA,nrow=NROW(C)+1,ncol=ncol(C)+1)
   C.int[1,] <- C.int[,1] <- 0
-  C.int[-1,-1] <-C
+  C.int[-1,-1] <- C
  if(!raw) { std <- TRUE
      C.int[1,1] <- 1
      means <- rep(0,NCOL(data))} else {
      C.int[1,1] <- 0 
-    if(!std){ means <-colMeans(data,na.rm=TRUE)} else { means <- rep(0,ncol(C))}
+    if(!std){ means <- colMeans(data,na.rm=TRUE)} else { means <- rep(0,ncol(C))}
      means <- c(1,means)
      C.int <- C.int *  (n.obs-1) + means %*% t(means) * n.obs
      } 
@@ -299,6 +305,7 @@ matReg <- function(x,y,C,m=NULL,z=NULL,n.obs=0,means=NULL,std=FALSE,raw=TRUE,par
       yhat <- t(C[x,y,drop=FALSE]) %*% x.inv %*% C[x,y,drop=FALSE]
       resid <- C[y,y]- yhat
       
+
      if(!std ) {
         df <- n.obs - numx - numz
 
@@ -483,13 +490,14 @@ boot.mediate <- function(data,x,y,m,z,n.iter=10,std=FALSE,use="pairwise") {
      dv <- medi$var.names[["DV"]]
    # iv <- medi$var.names[["IV"]]
      iv <- as.matrix(rownames(medi$direct))
-     if(iv[1] =="Intercept") iv <- iv[-1]
+     if(iv[1] =="Intercept") {iv <- iv[-1]
+            direct <- round(medi$direct[-1,,drop=FALSE],digits)} else { direct <- round(medi$direct,digits)}
     mv <- medi$var.names[["med"]]
     mod <- medi$var.names[["mod"]]
    # numx <- length(medi$var.names[["IV"]])
 
     numy <- length(dv)
-    direct <- round(medi$direct,digits)
+   # direct <- round(medi$direct,digits)
     if(!("Intercept*" %in% rownames(C))) {iv <- as.matrix(rownames(medi$direct)[-1])}
        numx <- NROW(iv)
     C <- round(medi$C[c(iv,mv,dv),c(iv,mv,dv)],digits) 
@@ -599,9 +607,10 @@ xlim=c(0,10)
 #plot(NA,xlim=xlim,ylim=ylim,main=main,axes=FALSE,xlab="",ylab="")
 var.names <- rownames(medi$direct)
 x.names <- rownames(medi$direct)
-if(x.names[1] == "Intercept") x.names <- x.names[-1]
+if(x.names[1] == "Intercept") {x.names <- x.names[-1]
+ beta <- round(medi$direct[-1,,drop=FALSE],digits)} else { beta <- round(medi$direct,digits)}   #fixed 10/29/20
 y.names <- colnames(medi$direct)
-beta <- round(medi$direct,digits)
+#beta <- round(medi$direct,digits)
 
 nx <- length(x.names)
 ny <- length(y.names)
